package ink.wgink.module.article.service.content;

import ink.wgink.interfaces.article.IArticleCheckService;
import ink.wgink.module.article.pojo.dtos.content.ContentDTO;
import ink.wgink.module.article.pojo.vos.content.ContentVO;
import ink.wgink.pojo.ListPage;
import ink.wgink.pojo.result.SuccessResultList;

import java.util.List;
import java.util.Map;

/**
 * @ClassName: IArticleContentService
 * @Description: 文章内容
 * @Author: WenG
 * @Date: 2020-04-03 15:37
 * @Version: 1.0
 **/
public interface IContentService extends IArticleCheckService {

    /**
     * 新增文章内容
     *
     * @param contentVO
     * @return
     */
    void save(ContentVO contentVO);

    /**
     * 新增文章内容(APP)
     *
     * @param token
     * @param contentVO
     * @return
     */
    void saveByToken(String token, ContentVO contentVO);

    /**
     * 删除文章内容
     *
     * @param ids
     * @return
     */
    void remove(List<String> ids);

    /**
     * 删除文章内容(APP)
     *
     * @param token
     * @param ids
     * @return
     */
    void removeByToken(String token, List<String> ids);

    /**
     * 修改文章内容
     *
     * @param contentId
     * @param contentVO
     * @return
     * @throws Exception
     */
    void update(String contentId, ContentVO contentVO);

    /**
     * 修改文章内容(APP)
     *
     * @param token
     * @param contentId
     * @param contentVO
     * @return
     * @throws Exception
     */
    void updateByToken(String token, String contentId, ContentVO contentVO);

    /**
     * 修改文章发布状态
     *
     * @param contentId
     * @param isPublish
     * @return
     */
    void updatePublishStatus(String contentId, Integer isPublish);

    /**
     * 文章内容详情(通过ID)
     *
     * @param contentId
     * @return
     */
    ContentDTO get(String contentId);

    /**
     * 文章内容列表
     *
     * @param params
     * @return
     */
    List<ContentDTO> list(Map<String, Object> params);

    /**
     * 文章内容分页列表
     *
     * @param page
     * @return
     */
    SuccessResultList<List<ContentDTO>> listPage(ListPage page);

    /**
     * 统计文章数量
     *
     * @param params
     * @return
     */
    Integer count(Map<String, Object> params);

}
